.. nodoctest

Multidimensional Continued Fraction Algorithms
==============================================

.. automodule:: slabbe.mult_cont_frac
   :members:
   :undoc-members:
   :show-inheritance:
   
.. automodule:: slabbe.mult_cont_frac_pyx
   :members:
   :undoc-members:
   :show-inheritance:
